# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/metric_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/metric_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%fsai_grpc_api/protos/metric_api.proto\x1a fsai_grpc_api/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x1c\n\x0bMetricValue\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\"k\n\x11MetricValueStruct\x12*\n\tdata_dict\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\tdata_list\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"7\n!FindMissionDetectionsCountRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"c\n\"FindMissionDetectionsCountResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue\"b\n(FindMissionDetectionCountsByStateRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\x12\"\n\x1a\x65xclude_single_pole_pylons\x18\x02 \x01(\x08\"p\n)FindMissionDetectionCountsByStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.MetricValueStruct\"6\n GetTotalImagesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"b\n!GetTotalImagesByMissionIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.MetricValue2\xd2\x02\n\tMetricApi\x12\x65\n\x1a\x46indMissionDetectionCounts\x12\".FindMissionDetectionsCountRequest\x1a#.FindMissionDetectionsCountResponse\x12z\n!FindMissionDetectionCountsByState\x12).FindMissionDetectionCountsByStateRequest\x1a*.FindMissionDetectionCountsByStateResponse\x12\x62\n\x19GetTotalImagesByMissionId\x12!.GetTotalImagesByMissionIdRequest\x1a\".GetTotalImagesByMissionIdResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_METRICVALUE = _descriptor.Descriptor(
  name='MetricValue',
  full_name='MetricValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='MetricValue.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=133,
)


_METRICVALUESTRUCT = _descriptor.Descriptor(
  name='MetricValueStruct',
  full_name='MetricValueStruct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_dict', full_name='MetricValueStruct.data_dict', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_list', full_name='MetricValueStruct.data_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=242,
)


_FINDMISSIONDETECTIONSCOUNTREQUEST = _descriptor.Descriptor(
  name='FindMissionDetectionsCountRequest',
  full_name='FindMissionDetectionsCountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='FindMissionDetectionsCountRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=299,
)


_FINDMISSIONDETECTIONSCOUNTRESPONSE = _descriptor.Descriptor(
  name='FindMissionDetectionsCountResponse',
  full_name='FindMissionDetectionsCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindMissionDetectionsCountResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FindMissionDetectionsCountResponse.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=400,
)


_FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST = _descriptor.Descriptor(
  name='FindMissionDetectionCountsByStateRequest',
  full_name='FindMissionDetectionCountsByStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='FindMissionDetectionCountsByStateRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_single_pole_pylons', full_name='FindMissionDetectionCountsByStateRequest.exclude_single_pole_pylons', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=500,
)


_FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE = _descriptor.Descriptor(
  name='FindMissionDetectionCountsByStateResponse',
  full_name='FindMissionDetectionCountsByStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindMissionDetectionCountsByStateResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='FindMissionDetectionCountsByStateResponse.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=614,
)


_GETTOTALIMAGESBYMISSIONIDREQUEST = _descriptor.Descriptor(
  name='GetTotalImagesByMissionIdRequest',
  full_name='GetTotalImagesByMissionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetTotalImagesByMissionIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=670,
)


_GETTOTALIMAGESBYMISSIONIDRESPONSE = _descriptor.Descriptor(
  name='GetTotalImagesByMissionIdResponse',
  full_name='GetTotalImagesByMissionIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetTotalImagesByMissionIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='GetTotalImagesByMissionIdResponse.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=770,
)

_METRICVALUESTRUCT.fields_by_name['data_dict'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_METRICVALUESTRUCT.fields_by_name['data_list'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FINDMISSIONDETECTIONSCOUNTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDMISSIONDETECTIONSCOUNTRESPONSE.fields_by_name['value'].message_type = _METRICVALUE
_FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE.fields_by_name['value'].message_type = _METRICVALUESTRUCT
_GETTOTALIMAGESBYMISSIONIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETTOTALIMAGESBYMISSIONIDRESPONSE.fields_by_name['value'].message_type = _METRICVALUE
DESCRIPTOR.message_types_by_name['MetricValue'] = _METRICVALUE
DESCRIPTOR.message_types_by_name['MetricValueStruct'] = _METRICVALUESTRUCT
DESCRIPTOR.message_types_by_name['FindMissionDetectionsCountRequest'] = _FINDMISSIONDETECTIONSCOUNTREQUEST
DESCRIPTOR.message_types_by_name['FindMissionDetectionsCountResponse'] = _FINDMISSIONDETECTIONSCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['FindMissionDetectionCountsByStateRequest'] = _FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST
DESCRIPTOR.message_types_by_name['FindMissionDetectionCountsByStateResponse'] = _FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE
DESCRIPTOR.message_types_by_name['GetTotalImagesByMissionIdRequest'] = _GETTOTALIMAGESBYMISSIONIDREQUEST
DESCRIPTOR.message_types_by_name['GetTotalImagesByMissionIdResponse'] = _GETTOTALIMAGESBYMISSIONIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetricValue = _reflection.GeneratedProtocolMessageType('MetricValue', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUE,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:MetricValue)
  })
_sym_db.RegisterMessage(MetricValue)

MetricValueStruct = _reflection.GeneratedProtocolMessageType('MetricValueStruct', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUESTRUCT,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:MetricValueStruct)
  })
_sym_db.RegisterMessage(MetricValueStruct)

FindMissionDetectionsCountRequest = _reflection.GeneratedProtocolMessageType('FindMissionDetectionsCountRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONDETECTIONSCOUNTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionDetectionsCountRequest)
  })
_sym_db.RegisterMessage(FindMissionDetectionsCountRequest)

FindMissionDetectionsCountResponse = _reflection.GeneratedProtocolMessageType('FindMissionDetectionsCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONDETECTIONSCOUNTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionDetectionsCountResponse)
  })
_sym_db.RegisterMessage(FindMissionDetectionsCountResponse)

FindMissionDetectionCountsByStateRequest = _reflection.GeneratedProtocolMessageType('FindMissionDetectionCountsByStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionDetectionCountsByStateRequest)
  })
_sym_db.RegisterMessage(FindMissionDetectionCountsByStateRequest)

FindMissionDetectionCountsByStateResponse = _reflection.GeneratedProtocolMessageType('FindMissionDetectionCountsByStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:FindMissionDetectionCountsByStateResponse)
  })
_sym_db.RegisterMessage(FindMissionDetectionCountsByStateResponse)

GetTotalImagesByMissionIdRequest = _reflection.GeneratedProtocolMessageType('GetTotalImagesByMissionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTOTALIMAGESBYMISSIONIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:GetTotalImagesByMissionIdRequest)
  })
_sym_db.RegisterMessage(GetTotalImagesByMissionIdRequest)

GetTotalImagesByMissionIdResponse = _reflection.GeneratedProtocolMessageType('GetTotalImagesByMissionIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTOTALIMAGESBYMISSIONIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.metric_api_pb2'
  # @@protoc_insertion_point(class_scope:GetTotalImagesByMissionIdResponse)
  })
_sym_db.RegisterMessage(GetTotalImagesByMissionIdResponse)



_METRICAPI = _descriptor.ServiceDescriptor(
  name='MetricApi',
  full_name='MetricApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=773,
  serialized_end=1111,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindMissionDetectionCounts',
    full_name='MetricApi.FindMissionDetectionCounts',
    index=0,
    containing_service=None,
    input_type=_FINDMISSIONDETECTIONSCOUNTREQUEST,
    output_type=_FINDMISSIONDETECTIONSCOUNTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindMissionDetectionCountsByState',
    full_name='MetricApi.FindMissionDetectionCountsByState',
    index=1,
    containing_service=None,
    input_type=_FINDMISSIONDETECTIONCOUNTSBYSTATEREQUEST,
    output_type=_FINDMISSIONDETECTIONCOUNTSBYSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTotalImagesByMissionId',
    full_name='MetricApi.GetTotalImagesByMissionId',
    index=2,
    containing_service=None,
    input_type=_GETTOTALIMAGESBYMISSIONIDREQUEST,
    output_type=_GETTOTALIMAGESBYMISSIONIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METRICAPI)

DESCRIPTOR.services_by_name['MetricApi'] = _METRICAPI

# @@protoc_insertion_point(module_scope)
